@@ -29,7 +29,7 @@ stem_modified_hunspell <- function(words, complete = TRUE){
   })
 
   word_stem <- unify_stems(words, stems) %>%
-    dplyr::right_join(dplyr::data_frame(words = words), by = "words") %>%
+    dplyr::right_join(tibble::tibble(words = words), by = "words") %>%
     dplyr::mutate(stems = stems)
 
   if (complete == FALSE) {
